--
--
--	SOC Scanner
--	(VHDL)
--
--	Lauterbach Datentechnik GmbH
--
--


library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_arith.all;


entity SOC is
	port (
		LOAD: in STD_LOGIC;
		DATA: in STD_LOGIC;
		CLKIN: in STD_LOGIC;
		XIN: in STD_LOGIC_VECTOR (255 downto 0);
		T: out STD_LOGIC_VECTOR (31 downto 0);
		SYNCH: out STD_LOGIC;
		CLKOUT: out STD_LOGIC
	);
end SOC;

--}} End of automatically maintained section

architecture SOC of SOC is					

type CREG_TYPE is array (7 downto 0) of std_logic_vector(2 downto 0);

signal	PreSynch, PClock, PCNTres, RegLoad, PCLK:std_logic:='0';
signal	PCnt:std_logic_vector(2 downto 0):=(others=>'0');
signal	RegEnd, EPB:std_logic_vector(7 downto 0):=(others=>'0');
signal	OReg:std_logic_vector(31 downto 0):=(others=>'0');
signal	CReg, IReg:std_logic_vector(255 downto 0):=(others=>'0');
signal	Reg:CREG_TYPE;
signal	CntNull:std_logic:='0';	

begin

PCLK<=CLKIN;
CLKOUT<=PCLK;


-- Control Register
process(LOAD, DATA, CReg)
begin
	if LOAD'event and LOAD='1' then
		Creg(31)<=DATA;
		Creg(30 downto 0)<=CReg(31 downto 1);
	end if;
end process;

--	Registers 
--	Decoding...
DECODE00 : for i in 7 downto 0 generate
			Reg(i)(2 downto 0)<=CReg((2+i*4) downto i*4);
			RegEnd(i)<=CReg(3+(i*4));
		end generate;								  
		
--	Multiplexing
--	Counter
process(PCLK, PCNTres)
begin		
	if PCLK'event and PCLK='1' then
		if PCntRes='1' then
			PCnt<=(others=>'0');
		else
			PCnt<=unsigned(PCnt)+1;
		end if;
	end if;
end process;   

--	Strobes
process(PCLK, PCnt)	 
begin
	if PCLK'event and PCLK='1' then
		if unsigned(PCnt)=0 then
			PreSynch<='1';
		else
			PreSynch<='0';
		end if;
	end if;
end process;

process(PCLK, PreSynch)
begin
	if PCLK'event and PCLK='1' then
		SYNCH<=PreSynch;
	end if;
end process;

process(PCLK, PCNTres)
begin
	if PCLK'event and PCLK='1' then
		RegLoad<=PCntRes;
	end if;
end process;

process(RegEnd, PCnt)
variable i:integer;				 
variable q:std_logic;
begin				 
	q:='0';
	for i in 7 downto 0 loop
		if (unsigned(PCnt)=i) and RegEnd(i)='1' then
			q:='1';
		end if;
	end loop;
	PCntRes <= q;
end process;


process(PCLK, Reg, PCnt)
variable i,j :integer;	  
variable q:std_logic;
begin				  
	if PCLK'event and PCLK='1' then
		for j in 7 downto 0 loop
			q:='0';
			for i in 7 downto 0 loop
				if ((unsigned(Reg(i)(2 downto 0)) = j) and (unsigned(PCnt)=i)) then
					q:='1';		
				end if;
			end loop;	
			EPB(j)<=q;
		end loop;
	end if;
end process;

--	Input Registers

process(PCLK, RegLoad, XIN)
begin
	if PCLK'event and PCLK='1' then
		if RegLoad='1' then
			IReg(255 downto 0)	<=	XIN(255 downto 0);
		end if;
	end if;
end process;

--	Multiplexer
process(PCLK, EPB, XIN)
variable i, j:integer;
variable tmpData:std_logic_vector(31 downto 0);
begin
	if PCLK'event and PCLK='1' then	   
		tmpData:=(others=>'0');
		
		for i in 0 to 7 loop  
			for j in 31 downto 0 loop
				if IREG(j+32*i)='1' and EPB(i)='1' then
					tmpData(j) := '1';
				end if;
			end loop;
		end loop;  		
		OREG<=tmpData;		
	end if;
end process;

T(31 downto 0) <= OReg(31 downto 0);

end SOC;
